.. toctree::
   :maxdepth: 2

Transport tweaks
----------------

.. include:: /../../examples/hlapi/twisted/manager/cmdgen/custom-timeout-and-retries.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/hlapi/twisted/manager/cmdgen/custom-timeout-and-retries.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/hlapi/twisted/manager/cmdgen/custom-timeout-and-retries.py>` script.

See also: :doc:`library reference </docs/api-reference>`.
